create_data <- function() {
  # Read in everything
  #projects <- read.table('projects_with_enough_merges_and_success.csv', header=FALSE, sep=',', col.names=c('gh_project_name'))
  # Retroactively do this with the further refined dataset of 348 projects
  projects <- read.table('failafterpass-merge.csv', header=TRUE, sep=',')
  merges <- read.table('mergesperproject.csv', header=TRUE, sep=',')
  commits <- read.table('commitsperproject.csv', header=TRUE, sep=',')
  team_size <- read.table('max_gh_team_size_per_project.csv', header=TRUE, sep=',')
  builds <- read.table('number_of_builds_per_project.csv', header=TRUE, sep=',')
  branches <- read.table('number_of_branches_per_project.csv', header=TRUE, sep=',')
  
  
  # Keep only the projects in `projects` variable
  merges <- merges[merges$gh_project_name %in% projects$gh_project_name,]
  commits <- commits[commits$gh_project_name %in% projects$gh_project_name,]
  team_size <- team_size[team_size$gh_project_name %in% projects$gh_project_name,]
  builds <- builds[builds$gh_project_name %in% projects$gh_project_name,]
  branches <- branches[branches$gh_project_name %in% projects$gh_project_name,]
  
  # Make sure everything is sorted in the same manner
  projects <- projects[order(projects$gh_project_name),]
  merges <- merges[order(merges$gh_project_name),]
  commits <- commits[order(commits$gh_project_name),]
  team_size <- team_size[order(team_size$gh_project_name),]
  builds <- builds[order(builds$gh_project_name),]
  branches <- branches[order(branches$gh_project_name),]
  
  # Throw everything in a big frame
  result <- data.frame(project=projects$gh_project_name,
                       merges=merges$merges,
                       commits=commits$number_of_commits,
                       teamsize=team_size$max_team_size,
                       builds=builds$number_of_builds,
                       branches=branches$number_of_branches)
  
  return(result)
}

projects <- create_data()

make_mosaic <- function() {
  par(mfcol=c(3,2)) # To create a grid of plots
  plot(projects$commits, projects$merges, xlab='Number of commits', ylab='Number of merges', pch=18)
  #plot(projects$builds, projects$merges) # Pretty much the same as commits vs merges
  plot(projects$teamsize, projects$merges, xlab='Team size', ylab='Number of merges', pch=18)
  plot(projects$branches, projects$merges, xlab='Number of branches', ylab='Number of merges', pch=18)
  plot(projects$commits, projects$merges, xlab='Number of commits', ylab='Number of merges', pch=18, xlim=c(0, 2000), ylim=c(0, 1000))
  plot(projects$teamsize, projects$merges, xlab='Team size', ylab='Number of merges', xlim=c(0, 50), ylim=c(0, 2000), pch=18)
  plot(projects$branches, projects$merges, xlab='Number of branches', ylab='Number of merges', ylim=c(0, 1000), xlim=c(0, 400), pch=18)
  par(mfcol=c(1,1))
}
#pdf('output/scattermosaic.pdf')
make_mosaic()
#dev.off()

plot(projects$teamsize, projects$branches)

# Plots
#plot(commits$number_of_commits, merges$merges, xlab='Number of commits', ylab='Number of merges', pch=18)
#pdf('output/numberofcommitsmerges.pdf')
#plot(commits$number_of_commits, merges$merges, xlab='Number of commits', ylab='Number of merges', pch=18, xlim=c(0, 2000), ylim=c(0, 1000))
#dev.off()
#pdf('output/pctmerges.pdf')
#boxplot(merges$merges / commits$number_of_commits * 100, ylim=c(0, 100))
#dev.off()

